@@ -18,18 +18,19 @@
 
 set -e
 
-if [ "$#" -ne 3 ]; then
-    echo "Usage: backup.sh <app-container> <db-container> <backup-file>"
+if [ "$#" -ne 1 ]; then
+    echo "Usage: backup.sh <backup-file>"
 fi
 
-APP=$1
-DB=$2
-TARGET=$3
+APP="fat-ffipd-app"
+DB="fat-ffipd-db"
+TARGET=$1
 
 rm -rf backup
 mkdir backup
 
-docker exec -it "$APP" printenv > backup/.env
+docker-compose up --no-recreate -d
+docker exec "$APP" printenv > backup/.env
 docker exec "$DB" bash -c 'mysqldump --single-transaction \
     -h localhost -u $MYSQL_USER --password=$MYSQL_PASSWORD $MYSQL_DATABASE' \
      > backup/db.sql
